============
Contributing
============

Code of Conduct
===============

This project and repository is governed by Mozilla's code of conduct and
etiquette guidelines. For more details please see the `CODE_OF_CONDUCT.md file
<https://github.com/willkg/fillmore/blob/main/CODE_OF_CONDUCT.md>`_.


Development, conventions, etc
=============================

All our documentation is at `<https://fillmore.readthedocs.io/>`_.


Reporting Bugs
==============

For regular bugs, please report them `in the issue tracker
<https://github.com/willkg/fillmore/issues>`_.


Maintenance promise
===================

Rough maintenance promise:

* as soon as possible

  * will address security bugs

* within 6 months

  * will update Fillmore for new sentry_sdk and Python versions
  * will address major function bugs

* when free time is available, but low priority

  * might address minor bugs
  * might answer questions

New releases are driven by fixes for security bugs or major bugs and support
for new versions of sentry_sdk and Python.
